@@ -1,5 +1,7 @@
 #! /bin/bash
 
+#set -x 
+
 SDIR=`dirname $0` 
 
 #export LD_LIBRARY_PATH=$HOME/libav-0.8/lib:$LD_LIBRARY_PATH
@@ -23,9 +25,12 @@ SDIR=`dirname $0`
 #JAVA_HOME=/opt-linux-x86_64/j2se7
 #export J2RE_HOME JAVA_HOME
 
-if [ -e $SDIR/../../../gluegen/make/scripts/setenv-build-jogl-x86_64.sh ] ; then
-    . $SDIR/../../../gluegen/make/scripts/setenv-build-jogl-x86_64.sh
+if [ -e $SDIR/../../../gluegen/make/scripts/setenv-build-jogamp-x86_64.sh ] ; then
+    . $SDIR/../../../gluegen/make/scripts/setenv-build-jogamp-x86_64.sh
 fi
 
-. $SDIR/tests.sh  `which java` -d64 ../build-x86_64 $*
+export SWT_CLASSPATH=`pwd`/lib/swt/gtk-linux-x86_64/swt.jar
+#export SWT_CLASSPATH=/usr/local/projects/JOGL/SWT/swt-4.3.0/gtk-linux-x86_64/swt-debug.jar
+
+. $SDIR/tests.sh  `which java` -DummyArg ../build-x86_64 $*
 
