@@ -30,7 +30,6 @@ package jogamp.opengl.util.av.impl;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;
-import java.security.AccessController;
 import java.security.PrivilegedAction;
 
 import com.jogamp.opengl.GL;
@@ -38,6 +37,8 @@ import com.jogamp.opengl.GL2ES2;
 import com.jogamp.opengl.GLException;
 
 import com.jogamp.common.util.IOUtil;
+import com.jogamp.common.util.PropertyAccess;
+import com.jogamp.common.util.SecurityUtil;
 import com.jogamp.common.util.VersionNumber;
 import com.jogamp.gluegen.runtime.ProcAddressTable;
 import com.jogamp.opengl.util.TimeFrameI;
@@ -152,25 +153,56 @@ import jogamp.opengl.util.av.VideoPixelFormat;
  *   </ul></li>
  *   <li>MacOSX
  *   <ul>
+ *     <li>Building using Homebrew *
+ *     <ul>
+ *       <li>https://github.com/Homebrew/homebrew/wiki/Installation</li>
+ *       <li>https://trac.ffmpeg.org/wiki/CompilationGuide/MacOSX<pre>
+ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
+brew install ffmpeg
+ *       </pre></li>
+ *     </ul></li>
  *     <li>Builds
  *     <ul>
  *       <li>https://ffmpeg.org/download.html#build-mac</li>
  *     </ul></li>
- *     <li>Building using Homebrew *
- *     <ul>
- *       <li>https://github.com/Homebrew/homebrew/wiki/Installation</li>
- *       <li>https://trac.ffmpeg.org/wiki/CompilationGuide/MacOSX</li>
- *     </ul></li>
  *   </ul></li>
  *   <li>OpenIndiana/Solaris:<pre>
- *       pkg set-publisher -p http://pkg.openindiana.org/sfe-encumbered.
- *       pkt install pkg:/video/ffmpeg
+pkg set-publisher -p http://pkg.openindiana.org/sfe-encumbered.
+pkt install pkg:/video/ffmpeg
  *       </pre></li>
  * </ul>
  * </p>
  */
 public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
 
+    /**
+     * Defaults to {@code true} for now.
+     * However, in case we ship our own ffmpeg library this may change.
+     * <p>
+     * Property {@code jogl.ffmpeg.lib} set to {@code internal}
+     * will set {@code PREFER_SYSTEM_LIBS} to {@code false}.
+     * </p>
+     * <p>
+     * Non system internal libraries are named 'internal_<basename>',
+     * e.g. 'internal_avutil'.
+     * </p>
+     * <p>
+     * System default libraries are named '<basename>',
+     * e.g. 'avutil'.
+     * </p>
+     * <p>
+     * If {@code PREFER_SYSTEM_LIBS} is {@code true} (default),
+     * we lookup the default library first,
+     * then the versioned library names and last the internal library.
+     * </p>
+     * <p>
+     * If {@code PREFER_SYSTEM_LIBS} is {@code false},
+     * we lookup the internal library first,
+     * then the versioned library names and last the default library.
+     * </p>
+     */
+    /* pp */ static final boolean PREFER_SYSTEM_LIBS;
+
     /** POSIX ENOSYS {@value}: Function not implemented. FIXME: Move to GlueGen ?!*/
     private static final int ENOSYS = 38;
 
@@ -186,6 +218,10 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
     private static final boolean enableSwResample;
 
     static {
+        // PREFER_SYSTEM_LIBS default on all systems is true for now!
+        final String choice = PropertyAccess.getProperty("jogl.ffmpeg.lib", true);
+        PREFER_SYSTEM_LIBS = null == choice || !choice.equals("internal");
+
         final boolean libAVGood = FFMPEGDynamicLibraryBundleInfo.initSingleton();
         final boolean libAVVersionGood;
         if( FFMPEGDynamicLibraryBundleInfo.libsLoaded() ) {
@@ -386,7 +422,7 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
         final int audioQueueLimit;
         if( null != gl && STREAM_ID_NONE != getVID() ) {
             final GLContextImpl ctx = (GLContextImpl)gl.getContext();
-            AccessController.doPrivileged(new PrivilegedAction<Object>() {
+            SecurityUtil.doPrivileged(new PrivilegedAction<Object>() {
                 @Override
                 public Object run() {
                     final ProcAddressTable pt = ctx.getGLProcAddressTable();
