@@ -42,26 +42,23 @@ package jogamp.opengl.windows.wgl;
 
 import java.nio.Buffer;
 import java.nio.ShortBuffer;
-import java.security.AccessController;
 import java.security.PrivilegedAction;
-import java.util.Collection;
-import java.util.HashMap;
 import java.util.List;
 
-import javax.media.nativewindow.AbstractGraphicsConfiguration;
-import javax.media.nativewindow.AbstractGraphicsDevice;
-import javax.media.nativewindow.AbstractGraphicsScreen;
-import javax.media.nativewindow.DefaultGraphicsScreen;
-import javax.media.nativewindow.NativeSurface;
-import javax.media.nativewindow.ProxySurface;
-import javax.media.nativewindow.UpstreamSurfaceHook;
-import javax.media.opengl.GLCapabilities;
-import javax.media.opengl.GLCapabilitiesChooser;
-import javax.media.opengl.GLCapabilitiesImmutable;
-import javax.media.opengl.GLContext;
-import javax.media.opengl.GLDrawable;
-import javax.media.opengl.GLException;
-import javax.media.opengl.GLProfile;
+import com.jogamp.nativewindow.AbstractGraphicsConfiguration;
+import com.jogamp.nativewindow.AbstractGraphicsDevice;
+import com.jogamp.nativewindow.AbstractGraphicsScreen;
+import com.jogamp.nativewindow.DefaultGraphicsScreen;
+import com.jogamp.nativewindow.NativeSurface;
+import com.jogamp.nativewindow.ProxySurface;
+import com.jogamp.nativewindow.UpstreamSurfaceHook;
+import com.jogamp.opengl.GLCapabilities;
+import com.jogamp.opengl.GLCapabilitiesChooser;
+import com.jogamp.opengl.GLCapabilitiesImmutable;
+import com.jogamp.opengl.GLContext;
+import com.jogamp.opengl.GLDrawable;
+import com.jogamp.opengl.GLException;
+import com.jogamp.opengl.GLProfile;
 
 import jogamp.nativewindow.WrappedSurface;
 import jogamp.nativewindow.windows.GDI;
@@ -80,11 +77,15 @@ import jogamp.opengl.SharedResourceRunner;
 import com.jogamp.common.nio.PointerBuffer;
 import com.jogamp.common.util.PropertyAccess;
 import com.jogamp.common.util.ReflectionUtil;
+import com.jogamp.common.util.SecurityUtil;
+import com.jogamp.nativewindow.GenericUpstreamSurfacelessHook;
 import com.jogamp.nativewindow.windows.WindowsGraphicsDevice;
 import com.jogamp.opengl.GLExtensions;
 import com.jogamp.opengl.GLRendererQuirks;
 
 public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
+  private static final boolean DEBUG_SHAREDCTX = DEBUG  || GLContext.DEBUG;
+
   /**
    * Bug 1036: NVidia Windows Driver 'Threaded optimization' workaround.
    * <p>
@@ -154,7 +155,7 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
 
     synchronized(WindowsWGLDrawableFactory.class) {
         if( null == windowsWGLDynamicLookupHelper ) {
-            windowsWGLDynamicLookupHelper = AccessController.doPrivileged(new PrivilegedAction<DesktopGLDynamicLookupHelper>() {
+            windowsWGLDynamicLookupHelper = SecurityUtil.doPrivileged(new PrivilegedAction<DesktopGLDynamicLookupHelper>() {
                 @Override
                 public DesktopGLDynamicLookupHelper run() {
                     DesktopGLDynamicLookupHelper tmp;
@@ -188,11 +189,10 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
             } catch (final Exception jre) { /* n/a .. */ }
         }
 
-        sharedMap = new HashMap<String, SharedResourceRunner.Resource>();
-
         // Init shared resources off thread
         // Will be released via ShutdownHook
-        sharedResourceRunner = new SharedResourceRunner(new SharedResourceImplementation());
+        sharedResourceImplementation = new SharedResourceImplementation();
+        sharedResourceRunner = new SharedResourceRunner(sharedResourceImplementation);
         sharedResourceRunner.start();
     }
   }
@@ -212,9 +212,9 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
         sharedResourceRunner.stop();
         sharedResourceRunner = null;
     }
-    if(null != sharedMap) {
-        sharedMap.clear();
-        sharedMap = null;
+    if(null != sharedResourceImplementation) {
+        sharedResourceImplementation.clear();
+        sharedResourceImplementation = null;
     }
     defaultDevice = null;
     /**
@@ -228,15 +228,15 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
   }
 
   @Override
-  public GLDynamicLookupHelper getGLDynamicLookupHelper(final int profile) {
+  public final GLDynamicLookupHelper getGLDynamicLookupHelper(final int majorVersion, final int contextOptions) {
       return windowsWGLDynamicLookupHelper;
   }
 
   /* pp */ static String toHexString(final long l) { return "0x"+Long.toHexString(l); }
 
   private WindowsGraphicsDevice defaultDevice;
+  private SharedResourceImplementation sharedResourceImplementation;
   private SharedResourceRunner sharedResourceRunner;
-  private HashMap<String /*connection*/, SharedResourceRunner.Resource> sharedMap;
 
   @Override
   protected void enterThreadCriticalZone() {
@@ -275,7 +275,7 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
       }
 
       @Override
-      public final boolean isValid() {
+      public final boolean isAvailable() {
           return null != context;
       }
       @Override
@@ -287,7 +287,7 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
       @Override
       final public GLContextImpl getContext() { return context; }
       @Override
-      public GLRendererQuirks getRendererQuirks() {
+      public GLRendererQuirks getRendererQuirks(final GLProfile glp) {
           return null != context ? context.getRendererQuirks() : null;
       }
 
@@ -297,86 +297,85 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
       final boolean hasReadDrawable() { return hasARBReadDrawable; }
   }
 
-  class SharedResourceImplementation implements SharedResourceRunner.Implementation {
+  class SharedResourceImplementation extends SharedResourceRunner.AImplementation {
         @Override
-        public void clear() {
-            sharedMap.clear();
-        }
-        @Override
-        public SharedResourceRunner.Resource mapPut(final String connection, final SharedResourceRunner.Resource resource) {
-            return sharedMap.put(connection, resource);
-        }
-        @Override
-        public SharedResourceRunner.Resource mapGet(final String connection) {
-            return sharedMap.get(connection);
-        }
-        @Override
-        public Collection<SharedResourceRunner.Resource> mapValues() {
-            synchronized(sharedMap) {
-                return sharedMap.values();
-            }
-        }
-
-        @Override
-        public boolean isDeviceSupported(final String connection) {
+        public boolean isDeviceSupported(final AbstractGraphicsDevice device) {
             return true;
         }
 
         @Override
-        public SharedResourceRunner.Resource createSharedResource(final String connection) {
-            final WindowsGraphicsDevice sharedDevice = new WindowsGraphicsDevice(connection, AbstractGraphicsDevice.DEFAULT_UNIT);
-            sharedDevice.lock();
+        public SharedResourceRunner.Resource createSharedResource(final AbstractGraphicsDevice adevice) {
+            final WindowsGraphicsDevice device = new WindowsGraphicsDevice(adevice.getConnection(), adevice.getUnitID());
+            GLContextImpl context = null;
+            boolean contextIsCurrent = false;
+            device.lock();
             try {
-                final AbstractGraphicsScreen absScreen = new DefaultGraphicsScreen(sharedDevice, 0);
-                final GLProfile glp = GLProfile.get(sharedDevice, GLProfile.GL_PROFILE_LIST_MIN_DESKTOP, false);
+                final AbstractGraphicsScreen absScreen = new DefaultGraphicsScreen(device, 0);
+                final GLProfile glp = GLProfile.get(device, GLProfile.GL_PROFILE_LIST_MIN_DESKTOP, false);
                 if (null == glp) {
-                    throw new GLException("Couldn't get default GLProfile for device: "+sharedDevice);
+                    throw new GLException("Couldn't get default GLProfile for device: "+device);
                 }
                 final GLCapabilitiesImmutable caps = new GLCapabilities(glp);
-                final GLDrawableImpl sharedDrawable = createOnscreenDrawableImpl(createDummySurfaceImpl(sharedDevice, false, caps, caps, null, 64, 64));
-                sharedDrawable.setRealized(true);
+                final GLDrawableImpl drawable = createOnscreenDrawableImpl(createDummySurfaceImpl(device, false, caps, caps, null, 64, 64));
+                drawable.setRealized(true);
 
-                final GLContextImpl sharedContext  = (GLContextImpl) sharedDrawable.createContext(null);
-                if (null == sharedContext) {
-                    throw new GLException("Couldn't create shared context for drawable: "+sharedDrawable);
+                context  = (GLContextImpl) drawable.createContext(null);
+                if (null == context) {
+                    throw new GLException("Couldn't create shared context for drawable: "+drawable);
                 }
-                boolean hasARBPixelFormat;
-                boolean hasARBMultisample;
-                boolean hasARBPBuffer;
-                boolean hasARBReadDrawableAvailable;
-                sharedContext.makeCurrent();
-                try {
-                    hasARBPixelFormat = sharedContext.isExtensionAvailable(WGL_ARB_pixel_format);
-                    hasARBMultisample = sharedContext.isExtensionAvailable(WGL_ARB_multisample);
-                    hasARBPBuffer = sharedContext.isExtensionAvailable(GLExtensions.ARB_pbuffer);
-                    hasARBReadDrawableAvailable = sharedContext.isExtensionAvailable(WGL_ARB_make_current_read) &&
-                                            sharedContext.isFunctionAvailable(wglMakeContextCurrent);
-                } finally {
-                    sharedContext.release();
+                contextIsCurrent = GLContext.CONTEXT_NOT_CURRENT != context.makeCurrent();
+
+                final boolean allowsSurfacelessCtx;
+                final boolean hasARBPixelFormat;
+                final boolean hasARBMultisample;
+                final boolean hasARBPBuffer;
+                final boolean hasARBReadDrawableAvailable;
+                if( contextIsCurrent ) {
+                    if( context.getGLVersionNumber().compareTo(GLContext.Version3_0) >= 0 ) {
+                        allowsSurfacelessCtx = probeSurfacelessCtx(context, true /* restoreDrawable */);
+                    } else {
+                        setNoSurfacelessCtxQuirk(context);
+                        allowsSurfacelessCtx = false;
+                    }
+                    hasARBPixelFormat = context.isExtensionAvailable(WGL_ARB_pixel_format);
+                    hasARBMultisample = context.isExtensionAvailable(WGL_ARB_multisample);
+                    hasARBPBuffer = context.isExtensionAvailable(GLExtensions.ARB_pbuffer);
+                    hasARBReadDrawableAvailable = context.isExtensionAvailable(WGL_ARB_make_current_read) &&
+                                                  context.isFunctionAvailable(wglMakeContextCurrent);
+                } else {
+                    allowsSurfacelessCtx = false;
+                    hasARBPixelFormat = false;
+                    hasARBMultisample = false;
+                    hasARBPBuffer = false;
+                    hasARBReadDrawableAvailable = false;
                 }
-                if (DEBUG) {
-                    System.err.println("SharedDevice:  " + sharedDevice);
+                if ( DEBUG_SHAREDCTX ) {
+                    System.err.println("SharedDevice:  " + device);
                     System.err.println("SharedScreen:  " + absScreen);
-                    System.err.println("SharedContext: " + sharedContext);
+                    System.err.println("SharedContext: " + context + ", madeCurrent " + contextIsCurrent);
+                    System.err.println("  allowsSurfacelessCtx "+allowsSurfacelessCtx);
                     System.err.println("pixelformat:   " + hasARBPixelFormat);
                     System.err.println("multisample:   " + hasARBMultisample);
                     System.err.println("pbuffer:       " + hasARBPBuffer);
                     System.err.println("readDrawable:  " + hasARBReadDrawableAvailable);
                 }
-                return new SharedResource(sharedDevice, absScreen, sharedDrawable, sharedContext,
+                return new SharedResource(device, absScreen, drawable, context,
                                           hasARBPixelFormat, hasARBMultisample,
                                           hasARBPBuffer, hasARBReadDrawableAvailable);
             } catch (final Throwable t) {
-                throw new GLException("WindowsWGLDrawableFactory - Could not initialize shared resources for "+connection, t);
+                throw new GLException("WindowsWGLDrawableFactory - Could not initialize shared resources for "+adevice, t);
             } finally {
-                sharedDevice.unlock();
+                if ( contextIsCurrent ) {
+                    context.release();
+                }
+                device.unlock();
             }
         }
 
         @Override
         public void releaseSharedResource(final SharedResourceRunner.Resource shared) {
             final SharedResource sr = (SharedResource) shared;
-            if (DEBUG) {
+            if ( DEBUG_SHAREDCTX ) {
               System.err.println("Shutdown Shared:");
               System.err.println("Device  : " + sr.device);
               System.err.println("Screen  : " + sr.screen);
@@ -444,6 +443,33 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
     return null;
   }
 
+  /**
+   * {@inheritDoc}
+   * <p>
+   * This factory always supports native desktop OpenGL profiles.
+   * </p>
+   */
+  @Override
+  public final boolean hasOpenGLDesktopSupport() { return true; }
+
+  /**
+   * {@inheritDoc}
+   * <p>
+   * This factory never supports native GLES profiles.
+   * </p>
+   */
+  @Override
+  public final boolean hasOpenGLESSupport() { return false; }
+
+  /**
+   * {@inheritDoc}
+   * <p>
+   * Always returns true.
+   * </p>
+   */
+  @Override
+  public final boolean hasMajorMinorCreateContextARB() { return true; }
+
   @Override
   protected List<GLCapabilitiesImmutable> getAvailableCapabilitiesImpl(final AbstractGraphicsDevice device) {
     return WindowsWGLGraphicsConfigurationFactory.getAvailableCapabilities(this, device);
@@ -554,6 +580,13 @@ public class WindowsWGLDrawableFactory extends GLDrawableFactoryImpl {
     return new GDISurface(config, 0, new GDIDummyUpstreamSurfaceHook(width, height), createNewDevice);
   }
 
+  @Override
+  public final ProxySurface createSurfacelessImpl(final AbstractGraphicsDevice deviceReq, final boolean createNewDevice,
+          GLCapabilitiesImmutable chosenCaps, final GLCapabilitiesImmutable requestedCaps, final GLCapabilitiesChooser chooser, final int width, final int height) {
+    chosenCaps = GLGraphicsConfigurationUtil.fixOnscreenGLCapabilities(chosenCaps);
+    return createMutableSurfaceImpl(deviceReq, createNewDevice, chosenCaps, requestedCaps, chooser, new GenericUpstreamSurfacelessHook(width, height));
+  }
+
   @Override
   protected final ProxySurface createProxySurfaceImpl(final AbstractGraphicsDevice deviceReq, final int screenIdx, final long windowHandle, final GLCapabilitiesImmutable capsRequested, final GLCapabilitiesChooser chooser, final UpstreamSurfaceHook upstream) {
     final WindowsGraphicsDevice device = new WindowsGraphicsDevice(deviceReq.getConnection(), deviceReq.getUnitID());
