@@ -53,7 +53,6 @@ import java.awt.event.ComponentEvent;
 import java.awt.event.ComponentListener;
 import java.awt.event.HierarchyEvent;
 import java.awt.event.HierarchyListener;
-import java.applet.Applet;
 
 import com.jogamp.nativewindow.AbstractGraphicsConfiguration;
 import com.jogamp.nativewindow.AbstractGraphicsDevice;
@@ -89,18 +88,17 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
 
   // lifetime: forever
   protected final Component component;
-  private final AppContextInfo appContextInfo;
+  private final AppContextInfo appContextInfo; // only used for offscreen layer, i.e. MacOS only
   private final SurfaceUpdatedHelper surfaceUpdatedHelper = new SurfaceUpdatedHelper();
   private final RecursiveLock surfaceLock = LockFactory.createRecursiveLock();
   private final JAWTComponentListener jawtComponentListener;
   private volatile AWTGraphicsConfiguration awtConfig; // control access through delegation
 
   // lifetime: valid after lock but may change with each 1st lock, purges after invalidate
-  private boolean isApplet;
   private JAWT jawt;
   private boolean isOffscreenLayerSurface;
   protected long drawable;
-  protected Rectangle bounds;
+  protected Rectangle jawt_surface_bounds;
   protected Insets insets;
   private volatile long offscreenSurfaceLayer;
 
@@ -125,13 +123,16 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
     if(! ( config instanceof AWTGraphicsConfiguration ) ) {
         throw new NativeWindowException("Error: AbstractGraphicsConfiguration is not an AWTGraphicsConfiguration: "+config);
     }
-    appContextInfo = new AppContextInfo("<init>");
+    if( JAWTUtil.isOffscreenLayerSupported() ) {
+        appContextInfo = new AppContextInfo("<init>");
+    } else {
+        appContextInfo = null;
+    }
     this.component = (Component)comp;
     this.jawtComponentListener = new JAWTComponentListener();
+    this.offscreenSurfaceLayer = 0;
     invalidate();
     this.awtConfig = (AWTGraphicsConfiguration) config;
-    this.isApplet = false;
-    this.offscreenSurfaceLayer = 0;
     if(DEBUG) {
         System.err.println(jawtStr2("ctor"));
     }
@@ -267,13 +268,18 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
         }
         // Thread.dumpStack();
     }
-    invalidateNative();
+    {
+        final long osl = offscreenSurfaceLayer;
+        offscreenSurfaceLayer = 0;
+        invalidateNative(osl);
+    }
     jawt = null;
     awtConfig = null;
+    offscreenSurfaceLayer = 0; // Bug 1389
     isOffscreenLayerSurface = false;
     drawable= 0;
     drawable_old = 0;
-    bounds = new Rectangle();
+    jawt_surface_bounds = new Rectangle();
     insets = new Insets();
     hasPixelScale[0] = ScalableSurface.IDENTITY_PIXELSCALE;
     hasPixelScale[1] = ScalableSurface.IDENTITY_PIXELSCALE;
@@ -283,7 +289,7 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
     maxPixelScale[1] = ScalableSurface.IDENTITY_PIXELSCALE;
     hasPixelScaleChanged = false;
   }
-  protected abstract void invalidateNative();
+  protected abstract void invalidateNative(final long _offscreenSurfaceLayer);
 
   /**
    * Set a new {@link AWTGraphicsConfiguration} instance,
@@ -353,13 +359,13 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
    */
   protected final boolean updateLockedData(final JAWT_Rectangle jawtBounds, final GraphicsConfiguration gc) {
     final Rectangle jb = new Rectangle(jawtBounds.getX(), jawtBounds.getY(), jawtBounds.getWidth(), jawtBounds.getHeight());
-    final boolean changedBounds = !bounds.equals(jb);
+    final boolean changedBounds = !jawt_surface_bounds.equals(jb);
 
     if( changedBounds ) {
         if( DEBUG ) {
-            System.err.println("JAWTWindow.updateBounds: "+bounds+" -> "+jb);
+            System.err.println("JAWTWindow.updateBounds: "+jawt_surface_bounds+" -> "+jb);
         }
-        bounds.set(jawtBounds.getX(), jawtBounds.getY(), jawtBounds.getWidth(), jawtBounds.getHeight());
+        jawt_surface_bounds.set(jawtBounds.getX(), jawtBounds.getY(), jawtBounds.getWidth(), jawtBounds.getHeight());
 
         if(component instanceof Container) {
             final java.awt.Insets contInsets = ((Container)component).getInsets();
@@ -402,26 +408,6 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
           return hasPixelScaleChanged;
       }
   }
-  /**
-   * @deprecated Use {@link #updatePixelScale(GraphicsConfiguration, boolean)}.
-   */
-  public final boolean updatePixelScale(final boolean clearFlag) {
-      return updatePixelScale(awtConfig.getAWTGraphicsConfiguration(), clearFlag);
-  }
-
-  /**
-   * @deprecated Use {@link #updateLockedData(JAWT_Rectangle, GraphicsConfiguration)}.
-   */
-  protected final boolean updateLockedData(final JAWT_Rectangle jawtBounds) {
-      throw new RuntimeException("Invalid API entry");
-  }
-  /**
-   * @deprecated Use {@link #lockSurfaceImpl(GraphicsConfiguration)}
-   */
-  protected int lockSurfaceImpl() throws NativeWindowException {
-      throw new RuntimeException("Invalid API entry");
-  }
-
 
   /**
    * Returns and clears the {@code hasPixelScaleChanged} flag, as set via {@link #lockSurface()}.
@@ -449,8 +435,8 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
     return SurfaceScaleUtils.setNewPixelScale(hasPixelScale, hasPixelScale, reqPixelScale, minPixelScale, maxPixelScale, DEBUG ? getClass().getSimpleName() : null);
   }
 
-  /** @return the JAWT_DrawingSurfaceInfo's (JAWT_Rectangle) bounds, updated with lock */
-  public final RectangleImmutable getBounds() { return bounds; }
+  /** @return the JAWT_DrawingSurfaceInfo's (JAWT_Rectangle) bounds in pixel units, updated with lock */
+  public final RectangleImmutable getJAWTSurfaceBounds() { return jawt_surface_bounds; }
 
   /** @return the safe pixelScale value for x-direction, i.e. never negative or zero. Updated with lock. */
   protected final float getPixelScaleX() { return hasPixelScale[0]; }
@@ -466,11 +452,14 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
   }
 
   /**
-   * Returns true if the AWT component is parented to an {@link java.applet.Applet},
+   *
+   * Return false since there is no more {@link java.applet.Applet} support.
+   *
+   * Historical: Returns true if the AWT component is parented to an {@link java.applet.Applet},
    * otherwise false. This information is valid only after {@link #lockSurface()}.
    */
   public final boolean isApplet() {
-      return isApplet;
+      return false; // return isApplet;
   }
 
   /** Returns the underlying JAWT instance created @ {@link #lockSurface()}. */
@@ -503,6 +492,9 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
 
   @Override
   public final void attachSurfaceLayer(final long layerHandle) throws NativeWindowException {
+      if( null == appContextInfo ) { // !JAWTUtil.isOffscreenLayerSupported()
+          throw new NativeWindowException("Offscreen layer not supported");
+      }
       if( !isOffscreenLayerSurfaceEnabled() ) {
           throw new NativeWindowException("Not an offscreen layer surface");
       }
@@ -522,7 +514,7 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
               }
           } };
 
-  protected void attachSurfaceLayerImpl(final long layerHandle) {
+  protected void attachSurfaceLayerImpl(final long _offscreenSurfaceLayer) {
       throw new UnsupportedOperationException("offscreen layer not supported");
   }
 
@@ -539,11 +531,11 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
    * @see #isOffscreenLayerSurfaceEnabled()
    * @throws NativeWindowException if {@link #isOffscreenLayerSurfaceEnabled()} == false
    */
-  protected void layoutSurfaceLayerImpl(final long layerHandle, final boolean visible) {}
+  protected void layoutSurfaceLayerImpl(final boolean visible) {}
 
   private final void layoutSurfaceLayerIfEnabled(final boolean visible) throws NativeWindowException {
       if( isOffscreenLayerSurfaceEnabled() && 0 != offscreenSurfaceLayer ) {
-          layoutSurfaceLayerImpl(offscreenSurfaceLayer, visible);
+          layoutSurfaceLayerImpl(visible);
       }
   }
 
@@ -554,21 +546,19 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
           throw new NativeWindowException("No offscreen layer attached: "+this);
       }
       if(DEBUG) {
-        System.err.println("JAWTWindow.detachSurfaceHandle(): osh "+toHexString(offscreenSurfaceLayer));
+        System.err.println("JAWTWindow.detachSurfaceHandle(): osh "+toHexString(offscreenSurfaceLayer)+" - "+Thread.currentThread().getName());
+      }
+      {
+          final long osl = offscreenSurfaceLayer;
+          offscreenSurfaceLayer = 0;
+          detachSurfaceLayerImpl(osl);
       }
-      detachSurfaceLayerImpl(offscreenSurfaceLayer, detachSurfaceLayerNotify);
   }
-  private final Runnable detachSurfaceLayerNotify = new Runnable() {
-    @Override
-    public void run() {
-        offscreenSurfaceLayer = 0;
-    }
-  };
 
   /**
    * @param detachNotify Runnable to be called before native detachment
    */
-  protected void detachSurfaceLayerImpl(final long layerHandle, final Runnable detachNotify) {
+  protected void detachSurfaceLayerImpl(final long _offscreenSurfaceLayer) {
       throw new UnsupportedOperationException("offscreen layer not supported");
   }
 
@@ -597,6 +587,7 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
   @Override
   public final boolean setCursor(final PixelRectangle pixelrect, final PointImmutable hotSpot) {
       AWTEDTExecutor.singleton.invoke(false, new Runnable() {
+          @Override
           public void run() {
               Cursor c = null;
               if( null == pixelrect || null == hotSpot ) {
@@ -619,6 +610,7 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
   @Override
   public final boolean hideCursor() {
       AWTEDTExecutor.singleton.invoke(false, new Runnable() {
+          @Override
           public void run() {
               final Cursor cursor = AWTMisc.getNullCursor();
               if( null != cursor ) {
@@ -632,13 +624,15 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
   // NativeSurface
   //
 
+  /**
   private void determineIfApplet() {
+    boolean isApplet = false; // dummy
     Component c = component;
     while(!isApplet && null != c) {
-        isApplet = c instanceof Applet;
+        isApplet = c instanceof java.applet.Applet;
         c = c.getParent();
     }
-  }
+  } */
 
   /**
    * If JAWT offscreen layer is supported,
@@ -684,7 +678,7 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
                 gc = awtConfig.getAWTGraphicsConfiguration();
             }
 
-            determineIfApplet();
+            // determineIfApplet();
             try {
                 final AbstractGraphicsDevice adevice = getGraphicsConfiguration().getScreen().getDevice();
                 adevice.lock();
@@ -821,6 +815,16 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
   // NativeWindow
   //
 
+  @Override
+  public final int getX() {
+      return component.getX();
+  }
+
+  @Override
+  public final int getY() {
+      return component.getY();
+  }
+
   @Override
   public final int getWidth() {
       return component.getWidth();
@@ -831,6 +835,18 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
       return component.getHeight();
   }
 
+  @Override
+  public final Rectangle getBounds() {
+      return new Rectangle(getX(), getY(), getWidth(), getHeight());
+  }
+
+  @Override
+  public final Rectangle getSurfaceBounds() {
+      return new Rectangle(SurfaceScaleUtils.scale(getX(), getPixelScaleX()),
+                           SurfaceScaleUtils.scale(getY(), getPixelScaleY()),
+                           getSurfaceWidth(), getSurfaceHeight());
+  }
+
   @Override
   public void destroy() {
     surfaceLock.lock();
@@ -855,16 +871,6 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
     return drawable;
   }
 
-  @Override
-  public final int getX() {
-      return component.getX();
-  }
-
-  @Override
-  public final int getY() {
-      return component.getY();
-  }
-
   /**
    * {@inheritDoc}
    *
@@ -928,10 +934,10 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
           sb.append("JAWT version: ").append(toHexString(jawt.getCachedVersion())).
           append(", CA_LAYER: ").append(JAWTUtil.isJAWTUsingOffscreenLayer(jawt)).
           append(", isLayeredSurface ").append(isOffscreenLayerSurfaceEnabled()).
-          append(", bounds ").append(bounds).append(", insets ").append(insets).
+          append(", bounds ").append(jawt_surface_bounds).append(", insets ").append(insets).
           append(", pixelScale ").append(getPixelScaleX()).append("x").append(getPixelScaleY());
       } else {
-          sb.append("JAWT n/a, bounds ").append(bounds).append(", insets ").append(insets);
+          sb.append("JAWT n/a, bounds ").append(jawt_surface_bounds).append(", insets ").append(insets);
       }
       return sb;
   }
@@ -946,7 +952,7 @@ public abstract class JAWTWindow implements NativeWindow, OffscreenLayerSurface,
                 ", attachedSurfaceLayer "+toHexString(getAttachedSurfaceLayer())+
                 ", windowHandle "+toHexString(getWindowHandle())+
                 ", surfaceHandle "+toHexString(getSurfaceHandle())+
-                ", bounds "+bounds+", insets "+insets
+                ", bounds "+jawt_surface_bounds+", insets "+insets
                 );
     sb.append(", window ["+getX()+"/"+getY()+" "+getWidth()+"x"+getHeight()+
              "], pixels[scale "+getPixelScaleX()+", "+getPixelScaleY()+" -> "+getSurfaceWidth()+"x"+getSurfaceHeight()+"]"+
