@@ -34,7 +34,6 @@
 
 package com.jogamp.newt.opengl;
 
-import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.List;
 
@@ -67,12 +66,14 @@ import com.jogamp.opengl.GLProfile;
 import com.jogamp.opengl.GLRunnable;
 import com.jogamp.opengl.GLSharedContextSetter;
 
+import jogamp.common.os.PlatformPropsImpl;
 import jogamp.newt.WindowImpl;
 import jogamp.opengl.GLAutoDrawableBase;
 import jogamp.opengl.GLContextImpl;
 import jogamp.opengl.GLDrawableImpl;
 
 import com.jogamp.common.GlueGenVersion;
+import com.jogamp.common.util.SecurityUtil;
 import com.jogamp.common.util.VersionUtil;
 import com.jogamp.common.util.locks.RecursiveLock;
 import com.jogamp.newt.MonitorDevice;
@@ -465,6 +466,11 @@ public class GLWindow extends GLAutoDrawableBase implements GLAutoDrawable, Wind
         return window.getSurfaceHeight();
     }
 
+    @Override
+    public final Rectangle getSurfaceBounds() {
+        return window.getSurfaceBounds();
+    }
+
     @Override
     public final int[] convertToWindowUnits(final int[] pixelUnitsAndResult) {
         return window.convertToWindowUnits(pixelUnitsAndResult);
@@ -534,10 +540,32 @@ public class GLWindow extends GLAutoDrawableBase implements GLAutoDrawable, Wind
         return window.isVisible();
     }
 
+    @Override
+    public final StringBuilder toSimpleString(final StringBuilder sb) {
+        sb.append("GLWindow[");
+        window.toSimpleString(sb).append("]");
+        return sb;
+    }
+    @Override
+    public final String toSimpleString() {
+        return toSimpleString(new StringBuilder()).toString();
+    }
+    @Override
+    public final StringBuilder toString(final StringBuilder sb) {
+        sb.append("GLWindow").append("[")
+        .append(PlatformPropsImpl.NEWLINE).append("\t").append("Helper: ").append(helper)
+        .append(", ").append(PlatformPropsImpl.NEWLINE).append("\t").append("Drawable: ").append(drawable)
+        .append(", ").append(PlatformPropsImpl.NEWLINE).append("\t").append("Context: ").append(context)
+        .append(", ").append(PlatformPropsImpl.NEWLINE).append("\t").append("Window: ");
+        window.toString(sb)
+        // .append(", ").append(Platform.NEWLINE).append("\t").append("Factory: ").append(factory)
+        .append("]");
+        return sb;
+    }
+
     @Override
     public final String toString() {
-        return "NEWT-GLWindow[ \n\tHelper: " + helper + ", \n\tDrawable: " + drawable +
-               ", \n\tContext: " + context + ", \n\tWindow: "+window+ /** ", \n\tFactory: "+factory+ */ "]";
+        return toString(new StringBuilder()).toString();
     }
 
     @Override
@@ -716,7 +744,7 @@ public class GLWindow extends GLAutoDrawableBase implements GLAutoDrawable, Wind
                 if( animThread == Thread.currentThread() ) {
                     anim.stop(); // on anim thread, non-blocking
                 } else {
-                    AccessController.doPrivileged(new PrivilegedAction<Object>() {
+                    SecurityUtil.doPrivileged(new PrivilegedAction<Object>() {
                         @Override
                         public Object run() {
                             if( anim.isAnimating() && null != animThread ) {
@@ -947,6 +975,11 @@ public class GLWindow extends GLAutoDrawableBase implements GLAutoDrawable, Wind
     // NativeWindow completion
     //
 
+    @Override
+    public RecursiveLock getLock() {
+        return window.getLock();
+    }
+
     @Override
     public final int lockSurface() throws NativeWindowException, RuntimeException {
         return window.lockSurface();
