@@ -34,8 +34,11 @@
 
 package jogamp.newt;
 
+import com.jogamp.common.ExceptionUtils;
 import com.jogamp.common.nio.Buffers;
 import com.jogamp.common.util.IOUtil;
+import com.jogamp.common.util.InterruptedRuntimeException;
+import com.jogamp.common.util.PropertyAccess;
 import com.jogamp.common.util.ReflectionUtil;
 import com.jogamp.newt.Display;
 import com.jogamp.newt.NewtFactory;
@@ -52,16 +55,17 @@ import java.net.URLConnection;
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 
-import javax.media.nativewindow.AbstractGraphicsDevice;
-import javax.media.nativewindow.NativeWindowException;
-import javax.media.nativewindow.NativeWindowFactory;
-import javax.media.nativewindow.util.PixelFormatUtil;
-import javax.media.nativewindow.util.PixelRectangle;
-import javax.media.nativewindow.util.PixelFormat;
-import javax.media.nativewindow.util.Point;
-import javax.media.nativewindow.util.PointImmutable;
+import com.jogamp.nativewindow.AbstractGraphicsDevice;
+import com.jogamp.nativewindow.NativeWindowException;
+import com.jogamp.nativewindow.NativeWindowFactory;
+import com.jogamp.nativewindow.util.PixelFormatUtil;
+import com.jogamp.nativewindow.util.PixelRectangle;
+import com.jogamp.nativewindow.util.PixelFormat;
+import com.jogamp.nativewindow.util.Point;
+import com.jogamp.nativewindow.util.PointImmutable;
 
 public abstract class DisplayImpl extends Display {
+    protected static final boolean DISABLE_POINTER_ICON = PropertyAccess.isPropertyDefined("newt.disable.PointerIcon", true);
     private static int serialno = 1;
     private static final boolean pngUtilAvail;
 
@@ -92,7 +96,7 @@ public abstract class DisplayImpl extends Display {
                 if(DEBUG) {
                     System.err.println("destroyAllPointerIconFromList: dpy "+toHexString(dpy)+", # "+i+"/"+count+": "+item+" @ "+getThreadName());
                 }
-                if( null != item && item.isValid() ) {
+                if( null != item ) {
                     item.destroyOnEDT(dpy);
                 }
             }
@@ -116,6 +120,8 @@ public abstract class DisplayImpl extends Display {
             return null;
         }
         final PointerIconImpl[] res = { null };
+        final Exception[] ex = { null };
+        final String exStr = "Could not resolve "+pngResource.resourcePaths[0];
         runOnEDTIfAvail(true, new Runnable() {
             public void run() {
                 try {
@@ -124,7 +130,7 @@ public abstract class DisplayImpl extends Display {
                     }
                     final URLConnection urlConn = pngResource.resolve(0);
                     if( null == urlConn ) {
-                        throw new IOException("Could not resolve "+pngResource.resourcePaths[0]);
+                        throw new IOException(exStr);
                     }
                     final PNGPixelRect image = PNGPixelRect.read(urlConn.getInputStream(),
                                                                  getNativePointerIconPixelFormat(),
@@ -138,14 +144,21 @@ public abstract class DisplayImpl extends Display {
                     }
                     if( 0 != handle ) {
                         res[0] = new PointerIconImpl(DisplayImpl.this, image, hotspot, handle);
-                        if( DEBUG_POINTER_ICON ) {
-                            System.err.println("createPointerIconPNG.0: "+res[0]);
-                        }
                     }
                 } catch (final Exception e) {
-                    e.printStackTrace();
+                    ex[0] = e;
                 }
             } } );
+        if( null != ex[0] ) {
+            final Exception e = ex[0];
+            if( e instanceof IllegalArgumentException) {
+                throw new IllegalArgumentException(e);
+            }
+            if( e instanceof IllegalStateException) {
+                throw new IllegalStateException(e);
+            }
+            throw new IOException(e);
+        }
         if( null != res[0] ) {
             synchronized(pointerIconList) {
                 pointerIconList.add(res[0]);
@@ -164,7 +177,7 @@ public abstract class DisplayImpl extends Display {
         final PixelRectangle fpixelrect;
         if( getNativePointerIconPixelFormat() != pixelrect.getPixelformat() || pixelrect.isGLOriented() ) {
             // conversion !
-            fpixelrect = PixelFormatUtil.convert32(pixelrect, getNativePointerIconPixelFormat(),
+            fpixelrect = PixelFormatUtil.convert(pixelrect, getNativePointerIconPixelFormat(),
                                                       0 /* ddestStride */, false /* isGLOriented */, getNativePointerIconForceDirectNIO() );
             if( DEBUG_POINTER_ICON ) {
                 System.err.println("createPointerIconRES.0: Conversion-FMT "+pixelrect+" -> "+fpixelrect);
@@ -229,7 +242,11 @@ public abstract class DisplayImpl extends Display {
         if( getNativePointerIconForceDirectNIO() && !Buffers.isDirect(pixels) ) {
             throw new IllegalArgumentException("pixel buffer is not direct "+pixels);
         }
-        return createPointerIconImpl(pixelformat, width, height, pixels, hotX, hotY);
+        if( !DISABLE_POINTER_ICON ) {
+            return createPointerIconImpl(pixelformat, width, height, pixels, hotX, hotY);
+        } else {
+            return 0;
+        }
     }
 
     /**
@@ -256,11 +273,7 @@ public abstract class DisplayImpl extends Display {
     private static Class<?> getDisplayClass(final String type)
         throws ClassNotFoundException
     {
-        final Class<?> displayClass = NewtFactory.getCustomClass(type, "DisplayDriver");
-        if(null==displayClass) {
-            throw new ClassNotFoundException("Failed to find NEWT Display Class <"+type+".DisplayDriver>");
-        }
-        return displayClass;
+        return NewtFactory.getCustomClass(type, "DisplayDriver");
     }
 
     /** Make sure to reuse a Display with the same name */
@@ -398,7 +411,7 @@ public abstract class DisplayImpl extends Display {
                 if( DEBUG ) {
                     if ( !res ) {
                         System.err.println("Warning: invokeStop() failed");
-                        Thread.dumpStack();
+                        ExceptionUtils.dumpStack(System.err);
                     }
                 }
             }
@@ -416,7 +429,7 @@ public abstract class DisplayImpl extends Display {
                 if( !_edtUtil.isRunning() ) { // // volatile dbl-checked-locking OK
                     if( DEBUG ) {
                         System.err.println("Info: EDT start "+Thread.currentThread().getName()+", "+this);
-                        Thread.dumpStack();
+                        ExceptionUtils.dumpStack(System.err);
                     }
                     _edtUtil.start();
                 }
@@ -428,7 +441,7 @@ public abstract class DisplayImpl extends Display {
             }
             if( DEBUG ) {
                 System.err.println("Warning: invoke(wait "+wait+", ..) on EDT failed .. invoke on current thread "+Thread.currentThread().getName());
-                Thread.dumpStack();
+                ExceptionUtils.dumpStack(System.err);
             }
         }
         task.run();
@@ -685,7 +698,7 @@ public abstract class DisplayImpl extends Display {
             if(null == event) {
                 // Ooops ?
                 System.err.println("Warning: event of eventTask is NULL");
-                Thread.dumpStack();
+                ExceptionUtils.dumpStack(System.err);
                 return;
             }
             dispatchMessage(event);
@@ -696,8 +709,9 @@ public abstract class DisplayImpl extends Display {
             } else {
                 throw re;
             }
+        } finally {
+            eventTask.notifyCaller();
         }
-        eventTask.notifyCaller();
     }
 
     @Override
@@ -724,7 +738,10 @@ public abstract class DisplayImpl extends Display {
             }
             if( null != _events ) {
                 for (int i=0; i < _events.size(); i++) {
-                    dispatchMessage(_events.get(i));
+                    final NEWTEventTask e = _events.get(i);
+                    if( !e.isDispatched() ) {
+                        dispatchMessage(e);
+                    }
                 }
             }
         }
@@ -739,7 +756,7 @@ public abstract class DisplayImpl extends Display {
             // oops .. we are already dead
             if(DEBUG) {
                 System.err.println("Warning: EDT already stopped: wait:="+wait+", "+e);
-                Thread.dumpStack();
+                ExceptionUtils.dumpStack(System.err);
             }
             return;
         }
@@ -758,11 +775,12 @@ public abstract class DisplayImpl extends Display {
                 haveEvents = true;
                 eventsLock.notifyAll();
             }
-            if( wait ) {
+            while( wait && !eTask.isDispatched() ) {
                 try {
                     lock.wait();
                 } catch (final InterruptedException ie) {
-                    throw new RuntimeException(ie);
+                    eTask.setDispatched(); // Cancels NEWTEvent ..
+                    throw new InterruptedRuntimeException(ie);
                 }
                 if( null != eTask.getException() ) {
                     throw eTask.getException();
