@@ -78,10 +78,11 @@ public class ScreenDriver extends ScreenImpl {
         props[i++] = 0; // rotation
         final MonitorMode currentMode = MonitorModeProps.streamInMonitorMode(null, cache, props, 0);
 
+        final int crt_id = 0;
         props = new int[MonitorModeProps.MIN_MONITOR_DEVICE_PROPERTIES - 1 - MonitorModeProps.NUM_MONITOR_MODE_PROPERTIES];
         i = 0;
         props[i++] = props.length;
-        props[i++] = 0; // crt_idx
+        props[i++] = crt_id;
         props[i++] = 0; // is-clone
         props[i++] = 1; // is-primary
         props[i++] = ScreenImpl.default_sm_widthmm; // FIXME
@@ -94,7 +95,7 @@ public class ScreenDriver extends ScreenImpl {
         props[i++] = 0; // rotated viewport y window-units
         props[i++] = cachedWidth; // rotated viewport width window-units
         props[i++] = cachedWidth; // rotated viewport height window-units
-        MonitorModeProps.streamInMonitorDevice(cache, this, currentMode, null, cache.monitorModes, props, 0, null);
+        MonitorModeProps.streamInMonitorDevice(cache, this, crt_id, null, currentMode, null, false, cache.monitorModes, props, 0, null);
     }
 
     @Override
