@@ -38,8 +38,9 @@ import com.jogamp.opengl.GLContext;
 import com.jogamp.opengl.GLProfile;
 
 import com.jogamp.opengl.util.Animator;
-import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
+import com.jogamp.opengl.test.junit.util.GLTestUtil;
 import com.jogamp.opengl.test.junit.util.MiscUtils;
+import com.jogamp.opengl.test.junit.util.NewtTestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
 import com.jogamp.opengl.test.junit.jogl.demos.es2.GearsES2;
 
@@ -129,24 +130,24 @@ public class TestSharedContextVBOES2NEWT3 extends UITestCase {
         animator.add(f2);
         f2.setVisible(true); // shall wait until f1 is ready
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f1, false));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f1, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f1, false, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f1, false, null));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f2, false));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f2, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f2, false, null));
 
         f1.setVisible(true); // kicks off f1 GLContext .. and hence gears of f2 + f3 completion
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f1, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f1, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f1, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f1, true, null));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f2, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f2, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f2, true, null));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
         final GearsES2 g3 = new GearsES2(0);
@@ -157,9 +158,9 @@ public class TestSharedContextVBOES2NEWT3 extends UITestCase {
         animator.add(f3);
         f3.setVisible(true); // shall wait until f1 is ready
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f3, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f3, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f3, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f3, true, null));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         final GLContext ctx1 = f1.getContext();
@@ -217,14 +218,32 @@ public class TestSharedContextVBOES2NEWT3 extends UITestCase {
             f3.destroy();
             try { Thread.sleep(durationPostDestroy); } catch(final Exception e) { e.printStackTrace(); }
         }
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f3, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f3, false));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f1, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f1, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f2, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f2, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f3, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f3, false, null));
 
         animator.stop();
+        {
+            final List<GLContext> ctx1Shares = ctx1.getCreatedShares();
+            final List<GLContext> ctx2Shares = ctx2.getCreatedShares();
+            final List<GLContext> ctx3Shares = ctx3.getCreatedShares();
+            MiscUtils.dumpSharedGLContext("XXX-C-3.1", ctx1);
+            MiscUtils.dumpSharedGLContext("XXX-C-3.2", ctx2);
+            MiscUtils.dumpSharedGLContext("XXX-C-3.3", ctx3);
+
+            Assert.assertTrue("Ctx1 is shared", !ctx1.isShared());
+            Assert.assertTrue("Ctx2 is shared", !ctx2.isShared());
+            Assert.assertTrue("Ctx3 is shared", !ctx3.isShared());
+            Assert.assertEquals("Ctx1 has unexpected number of created shares", 0, ctx1Shares.size());
+            Assert.assertEquals("Ctx2 has unexpected number of created shares", 0, ctx2Shares.size());
+            Assert.assertEquals("Ctx3 has unexpected number of created shares", 0, ctx3Shares.size());
+            Assert.assertEquals("Ctx1 Master Context is set", null, ctx1.getSharedMaster());
+            Assert.assertEquals("Ctx2 Master Context is set", null, ctx2.getSharedMaster());
+            Assert.assertEquals("Ctx3 Master Context is set", null, ctx3.getSharedMaster());
+        }
     }
 
     @Test
@@ -267,24 +286,24 @@ public class TestSharedContextVBOES2NEWT3 extends UITestCase {
         a2.start();
         f2.setVisible(true);
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f1, false));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f1, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f1, false, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f1, false, null));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f2, false));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f2, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f2, false, null));
 
         f1.setVisible(true); // test pending creation of f2
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f1, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f1, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f1, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f1, true, null));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f2, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f2, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f2, true, null));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
         final Animator a3 = new Animator();
@@ -297,9 +316,9 @@ public class TestSharedContextVBOES2NEWT3 extends UITestCase {
         a3.start();
         f3.setVisible(true);
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(f3, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f3, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f3, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(f3, true, null));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         final GLContext ctx1 = f1.getContext();
@@ -365,16 +384,16 @@ public class TestSharedContextVBOES2NEWT3 extends UITestCase {
             f3.destroy();
             try { Thread.sleep(durationPostDestroy); } catch(final Exception e) { e.printStackTrace(); }
         }
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(f3, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(f3, false));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f1, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f1, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f2, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f2, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(f3, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(f3, false, null));
     }
 
-    static long duration = 1000; // ms
-    static long durationPostDestroy = 1000; // ms - ~60 frames post destroy
+    static long duration = 1000; // ms - ~60 frames
+    static long durationPostDestroy = 170; // ms - ~10 frames post destroy
     static boolean mainRun = false;
 
     public static void main(final String args[]) {
