@@ -36,6 +36,7 @@ import com.jogamp.opengl.awt.GLJPanel;
 
 import com.jogamp.opengl.util.Animator;
 import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
+import com.jogamp.opengl.test.junit.util.GLTestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
 import com.jogamp.opengl.test.junit.jogl.demos.es2.GearsES2;
 
@@ -116,19 +117,19 @@ public class TestAnimatorGLJPanel01AWT extends UITestCase {
                 f3.setVisible(true);
             } } );
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c1, true));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c1, true, null));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c2, true));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c2, true, null));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c3, true));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c3, true, null));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         try {
@@ -168,9 +169,9 @@ public class TestAnimatorGLJPanel01AWT extends UITestCase {
                 }
             }});
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, false));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, false, null));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, false, null));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, false, null));
     }
 
     @Test
@@ -218,19 +219,19 @@ public class TestAnimatorGLJPanel01AWT extends UITestCase {
                 f3.setVisible(true);
             } } );
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c1, true));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c1, true, null));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c2, true));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c2, true, null));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c3, true));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c3, true, null));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         try {
@@ -276,9 +277,9 @@ public class TestAnimatorGLJPanel01AWT extends UITestCase {
                 }
             }});
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, false));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, false, null));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, false, null));
+        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, false, null));
     }
 
     static long duration = 3*500; // ms
