@@ -34,7 +34,8 @@ import com.jogamp.opengl.GLCapabilities;
 
 import com.jogamp.newt.opengl.GLWindow;
 import com.jogamp.opengl.util.Animator;
-import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
+import com.jogamp.opengl.test.junit.util.NewtTestUtil;
+import com.jogamp.opengl.test.junit.util.GLTestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
 import com.jogamp.opengl.test.junit.jogl.demos.es2.GearsES2;
 
@@ -108,19 +109,19 @@ public class TestAnimatorGLWindow01NEWT extends UITestCase {
         c2.setVisible(true);
         c3.setVisible(true);
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c1, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c1, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(c1, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c1, true, null));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c2, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c2, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(c2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c2, true, null));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c3, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c3, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(c3, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c3, true, null));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         try {
@@ -153,9 +154,9 @@ public class TestAnimatorGLWindow01NEWT extends UITestCase {
         c2.destroy();
         c3.destroy();
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, false));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c1, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c2, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c3, false, null));
     }
 
     @Test
@@ -191,19 +192,19 @@ public class TestAnimatorGLWindow01NEWT extends UITestCase {
         Assert.assertEquals(true, a3.isAnimating());
         c3.setVisible(true);
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c1, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c1, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(c1, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c1, true, null));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c2, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c2, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(c2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c2, true, null));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c3, true));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c3, true, null));
+        Assert.assertTrue(NewtTestUtil.waitForVisible(c3, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c3, true, null));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         try {
@@ -242,9 +243,9 @@ public class TestAnimatorGLWindow01NEWT extends UITestCase {
         c2.destroy();
         c3.destroy();
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, false));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c1, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c2, false, null));
+        Assert.assertTrue(NewtTestUtil.waitForRealized(c3, false, null));
     }
 
     static long duration = 3*500; // ms
