@@ -47,13 +47,16 @@ import com.jogamp.newt.awt.NewtCanvasAWT;
 import com.jogamp.newt.event.WindowEvent;
 import com.jogamp.newt.event.WindowAdapter;
 import com.jogamp.newt.opengl.GLWindow;
+import com.jogamp.newt.opengl.util.NEWTDemoListener;
 import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
 import com.jogamp.opengl.test.junit.util.MiscUtils;
+import com.jogamp.opengl.test.junit.util.NewtTestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
 import com.jogamp.opengl.util.Animator;
 import com.jogamp.opengl.util.AnimatorBase;
 import com.jogamp.opengl.test.junit.jogl.demos.es2.GearsES2;
 import com.jogamp.opengl.test.junit.newt.parenting.NewtAWTReparentingKeyAdapter;
+import com.jogamp.opengl.test.junit.newt.parenting.NewtReparentingKeyAdapter;
 
 import com.jogamp.nativewindow.ScalableSurface;
 import com.jogamp.nativewindow.util.Dimension;
@@ -73,6 +76,14 @@ import org.junit.Test;
 import org.junit.FixMethodOrder;
 import org.junit.runners.MethodSorters;
 
+/**
+ * <p>
+ * The demo code uses {@link NewtReparentingKeyAdapter} including {@link NEWTDemoListener} functionality.
+ * </p>
+ * <p>
+ * Manual invocation via main allows setting each tests's duration in milliseconds, e.g.{@code -duration 10000}, and many more, see {@link #main(String[])}
+ * </p>
+ */
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
 public class TestGearsES2NewtCanvasAWT extends UITestCase {
     public enum FrameLayout { None, TextOnBottom, BorderBottom, BorderBottom2, BorderCenter, BorderCenterSurrounded, DoubleBorderCenterSurrounded };
@@ -81,7 +92,7 @@ public class TestGearsES2NewtCanvasAWT extends UITestCase {
     static int screenIdx = 0;
     static PointImmutable wpos;
     static DimensionImmutable wsize, rwsize = null;
-    static FrameLayout frameLayout = FrameLayout.None;
+    static FrameLayout frameLayout = FrameLayout.BorderCenterSurrounded;
     static ResizeBy resizeBy = ResizeBy.Component;
     static float[] reqSurfacePixelScale = new float[] { ScalableSurface.AUTOMAX_PIXELSCALE, ScalableSurface.AUTOMAX_PIXELSCALE };
 
@@ -247,17 +258,21 @@ public class TestGearsES2NewtCanvasAWT extends UITestCase {
         final GearsES2 demo = new GearsES2(swapInterval);
         glWindow.addGLEventListener(demo);
 
+        final NewtAWTReparentingKeyAdapter newtDemoListener = new NewtAWTReparentingKeyAdapter(frame, newtCanvasAWT, glWindow);
+        newtDemoListener.quitAdapterEnable(true);
+        glWindow.addKeyListener(newtDemoListener);
+        glWindow.addMouseListener(newtDemoListener);
+        glWindow.addWindowListener(newtDemoListener);
+
         frame.addComponentListener(new ComponentListener() {
             @Override
             public void componentResized(final ComponentEvent e) {
-                NewtAWTReparentingKeyAdapter.setTitle(frame, newtCanvasAWT, glWindow);
+                newtDemoListener.setTitle();
             }
-
             @Override
             public void componentMoved(final ComponentEvent e) {
-                NewtAWTReparentingKeyAdapter.setTitle(frame, newtCanvasAWT, glWindow);
+                newtDemoListener.setTitle();
             }
-
             @Override
             public void componentShown(final ComponentEvent e) { }
 
@@ -280,12 +295,6 @@ public class TestGearsES2NewtCanvasAWT extends UITestCase {
             }
         });
 
-        final NewtAWTReparentingKeyAdapter newtDemoListener = new NewtAWTReparentingKeyAdapter(frame, newtCanvasAWT, glWindow);
-        newtDemoListener.quitAdapterEnable(true);
-        glWindow.addKeyListener(newtDemoListener);
-        glWindow.addMouseListener(newtDemoListener);
-        glWindow.addWindowListener(newtDemoListener);
-
         if( useAnimator ) {
             animator.add(glWindow);
             animator.start();
@@ -304,8 +313,8 @@ public class TestGearsES2NewtCanvasAWT extends UITestCase {
                frame.setVisible(true);
            }
         });
-        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, true));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glWindow, true));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, true, null));
+        Assert.assertEquals(true,  NewtTestUtil.waitForRealized(glWindow, true, null));
 
         if( useAnimator ) {
             animator.setUpdateFPSFrames(60, showFPS ? System.err : null);
@@ -319,7 +328,7 @@ public class TestGearsES2NewtCanvasAWT extends UITestCase {
         System.err.println("HiDPI PixelScale: "+reqSurfacePixelScale[0]+"x"+reqSurfacePixelScale[1]+" (req) -> "+
                            valReqSurfacePixelScale[0]+"x"+valReqSurfacePixelScale[1]+" (val) -> "+
                            hasSurfacePixelScale1[0]+"x"+hasSurfacePixelScale1[1]+" (has)");
-        NewtAWTReparentingKeyAdapter.setTitle(frame, newtCanvasAWT, glWindow);
+        newtDemoListener.setTitle();
 
         if( null != rwsize ) {
             Thread.sleep(500); // 500ms delay
@@ -347,7 +356,7 @@ public class TestGearsES2NewtCanvasAWT extends UITestCase {
            }
         });
         glWindow.destroy();
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glWindow, false));
+        Assert.assertEquals(true,  NewtTestUtil.waitForRealized(glWindow, false, null));
     }
 
     @Test
